public inbox for binutils@sourceware.org
 help / color / mirror / Atom feed
* PATCH: Use !intel_mnemonic instead of SYSV386_COMPAT
@ 2008-01-04 18:23 H.J. Lu
  0 siblings, 0 replies; only message in thread
From: H.J. Lu @ 2008-01-04 18:23 UTC (permalink / raw)
  To: binutils

I am checking in this to use  !intel_mnemonic instead of
SYSV386_COMPAT.

H.J.
---
2008-01-03  H.J. Lu  <hongjiu.lu@intel.com>

	* config/tc-i386.c (md_assemble): Use !intel_mnemonic instead
	of SYSV386_COMPAT.

--- config/tc-i386.c.intel	2008-01-03 17:05:56.000000000 -0800
+++ config/tc-i386.c	2008-01-03 17:22:08.000000000 -0800
@@ -2205,8 +2205,9 @@ md_assemble (line)
 
   if (intel_syntax)
     {
-      /* Undo SYSV386_COMPAT brokenness when in Intel mode.  See i386.h  */
-      if (SYSV386_COMPAT
+      /* Undo AT&T Mnemonic brokenness when in Intel mode.  See
+	 i386-opc.tbl.  */
+      if (!intel_mnemonic
 	  && (i.tm.base_opcode & 0xfffffde0) == 0xdce0)
 	i.tm.base_opcode ^= Opcode_FloatR;
 

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2008-01-04  1:31 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2008-01-04 18:23 PATCH: Use !intel_mnemonic instead of SYSV386_COMPAT H.J. Lu

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).